==> SimplyDualWielding-5.1.1%2B1.21.%282-4%29-Fabric-sources.jar: eva/dualwielding/config/SimplyDualWieldingConfig.java <==
package eva.dualwielding.config;

import eva.dualwielding.network.ConfigPacket;
import eva.dualwielding.network.ListPacket;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;
import java.util.function.Function;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_7923;

public class SimplyDualWieldingConfig {

    private boolean empty = false;
    private ItemCat attacks = ItemCat.ALL;
    private ItemCat mines = ItemCat.ALL;
    private List<String> attackList;
    private List<String> mineList;
    private List<String> disableUseList;
    private boolean[] allowWeakConfig = {false, false, false, false};
    private boolean respectIMMining = true;
    private boolean respectIMAttacking = true;
    private ConditionalBehavior restrictUse = ConditionalBehavior.SNEAKING_ONLY;

    private static SimplyDualWieldingConfig INSTANCE;
    private static SimplyDualWieldingConfig SERVER_INSTANCE;
    private static final List<String> def = new ArrayList<>();
    static {def.add("minecraft:air");}
    private static final List<String> defUseList = new ArrayList<>();
    static {
        defUseList.add("minecraft:wooden_axe");
        defUseList.add("minecraft:stone_axe");
        defUseList.add("minecraft:iron_axe");
        defUseList.add("minecraft:golden_axe");
        defUseList.add("minecraft:diamond_axe");
        defUseList.add("minecraft:netherite_axe");
        defUseList.add("minecraft:wooden_shovel");
        defUseList.add("minecraft:stone_shovel");
        defUseList.add("minecraft:iron_shovel");
        defUseList.add("minecraft:golden_shovel");
        defUseList.add("minecraft:diamond_shovel");
        defUseList.add("minecraft:netherite_shovel");
        defUseList.add("minecraft:wooden_hoe");
        defUseList.add("minecraft:stone_hoe");
        defUseList.add("minecraft:iron_hoe");
        defUseList.add("minecraft:golden_hoe");
        defUseList.add("minecraft:diamond_hoe");
        defUseList.add("minecraft:netherite_hoe");
    }
    private static ListState listState = ListState.ATTACK;

    private SimplyDualWieldingConfig() {
        attackList = def;
        mineList = def;
        disableUseList = defUseList;
    }

    public SimplyDualWieldingConfig(boolean empty, ItemCat attacks, ItemCat mines, ConditionalBehavior restrictUse, boolean[] allowWeakConfig) {
        this.empty = empty;
        this.attacks = attacks;
        this.mines = mines;
        this.restrictUse = restrictUse;
        this.allowWeakConfig = allowWeakConfig;
        attackList = def;
        mineList = def;
        disableUseList = defUseList;
    }

    public static SimplyDualWieldingConfig getInstance() {
        if (INSTANCE == null) {
            INSTANCE = new SimplyDualWieldingConfig();
        }
        return INSTANCE;
    }

    public static SimplyDualWieldingConfig getServerInstance() {
        return SERVER_INSTANCE;
    }

    private static void setServerInstance(SimplyDualWieldingConfig newInstance) {
        SERVER_INSTANCE = newInstance;
    }

    public void updateConfigs(SimplyDualWieldingConfig config) {
        this.empty = config.empty;
        this.attacks = config.attacks;
        this.mines = config.mines;
        this.restrictUse = config.restrictUse;
        setAttackItems(config.attackList);
        setMineItems(config.mineList);
        setDisableUseItems(config.disableUseList);
        this.allowWeakConfig = config.allowWeakConfig;
        this.respectIMMining = config.respectIMMining;
        this.respectIMAttacking = config.respectIMAttacking;
    }

    static void setEmpty(boolean setter) {
        getInstance().empty = setter;
    }
    public boolean getEmpty() {
        return this.empty;
    }

    static void setRestrictUse(ConditionalBehavior setter) {
        getInstance().restrictUse = setter;
    }
    public ConditionalBehavior getRestrictUse() {
        return this.restrictUse;
    }

    static void setAttacks(ItemCat setter) {
        getInstance().attacks = setter;
    }
    public ItemCat getAttacks() {
        return this.attacks;
    }

    static void setMines(ItemCat setter) {
        getInstance().mines = setter;
    }
    public ItemCat getMines() {
        return this.mines;
    }

    public List<String> getAttackItems() {
        return this.attackList;
    }
    static void setAttackItems(List<String> newList) {
        getInstance().attackList = newList;
    }

    public List<String> getMineItems() {
        return this.mineList;
    }
    static void setMineItems(List<String> newList) {
        getInstance().mineList = newList;
    }

    public List<String> getDisableUseItems() {
        return this.disableUseList;
    }
    static void setDisableUseItems(List<String> newList) {
        getInstance().disableUseList = newList;
    }

    public boolean getRespectIMAttacking() {
        return this.respectIMAttacking;
    }

    static void setRespectIMAttacking(boolean newVal) {
        getInstance().respectIMAttacking = newVal;
    }

    public boolean getRespectIMMining() {
        return this.respectIMMining;
    }

    static void setRespectIMMining(boolean newVal) {
        getInstance().respectIMMining = newVal;
    }

    public static Set<class_2960> getSetFromList (List<String> list) {
        Set<class_2960> set = ConcurrentHashMap.newKeySet();
        for (String nam : list)
            set.add(class_2960.method_60654(nam));
        return set;
    }

    public static void onConfigReceived(ConfigPacket payload) {
        setServerInstance(payload.getHeldInstance());
    }

    public static void onListReceived(ListPacket listPacket) {
        List<String> list = listPacket.getList();
        for (String entry : list) {
            switch (listState) {
                case ATTACK:
                    if (entry.isEmpty())
                        listState = ListState.MINE;
                    else
                        SERVER_INSTANCE.attackList.add(entry);
                    break;
                case MINE:
                    if (entry.isEmpty())
                        listState = ListState.USE_DISABLED;
                    else
                        SERVER_INSTANCE.mineList.add(entry);
                    break;
                case USE_DISABLED:
                    if (entry.isEmpty())
                        listState = ListState.ATTACK;
                    else
                        if (entry.equals("def"))
                            SERVER_INSTANCE.disableUseList.addAll(defUseList);
                        else
                            SERVER_INSTANCE.disableUseList.add(entry);

            }
        }
    }


    private static class ErrorSupplier implements Function<String, Optional<class_2561>> {
        @Override
        public Optional<class_2561> apply(String entry) {
            entry = entry.toLowerCase();
            if (entry.indexOf(':') != entry.lastIndexOf(':'))
                return Optional.of(class_2561.method_43470("Enter a valid item TYPE! error code: 1"));
            String name = entry.substring(entry.indexOf(':') + 1).replaceAll("[^a-z0-9/._-]", "");
            if (!entry.equals(name)) {
                if (entry.indexOf(':') == -1)
                    return Optional.of(class_2561.method_43470("Enter a valid item TYPE! error code: 2"));
                String namespace = entry.substring(0,entry.indexOf(':')).replaceAll("[^a-z0-9/._-]", "");
                if (!entry.equals(namespace + ":" + name)) {
                    return Optional.of(class_2561.method_43470("Enter a valid item TYPE! error code: 3"));
                }
            }
            class_2960 id = class_2960.method_60654(entry);
            if (!class_7923.field_41178.method_10235().contains(id))
                return Optional.of(class_2561.method_43470("Enter a valid item TYPE! error code: 4"));
            return Optional.empty();
        }
    }
    static Function<String, Optional<class_2561>> getErrorSupplier() {
        return new ErrorSupplier();
    }

    static List<String> getDef() {
        return def;
    }

    public static List<String> getDefUseList() {return defUseList;}

    public boolean[] getAllowWeakConfig() {
        return this.allowWeakConfig;
    }

    public boolean getAllowWeakConfig(int i) {
        return this.allowWeakConfig[i];
    }

    public static void disconnect() {
        if (SERVER_INSTANCE != null)
            SERVER_INSTANCE = null;
    }

    private enum ListState {
        ATTACK,
        MINE,
        USE_DISABLED
    }

}

==> SimplyDualWielding-6.1.2%2B1.21.%282-4%29-Fabric-sources.jar: eva/dualwielding/config/SimplyDualWieldingConfig.java <==
package eva.dualwielding.config;

import eva.dualwielding.config.enums.BalanceMode;
import eva.dualwielding.config.enums.ConditionalBehavior;
import eva.dualwielding.config.enums.ItemCat;
import eva.dualwielding.network.BalancePacket;
import eva.dualwielding.network.ConfigPacket;
import eva.dualwielding.network.ListPacket;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;
import java.util.function.Function;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_7923;

public class SimplyDualWieldingConfig {

    private boolean empty = false;
    private ItemCat attacks = ItemCat.ALL;
    private ItemCat mines = ItemCat.ALL;
    private List<String> attackList;
    private List<String> mineList;
    private List<String> disableUseList;
    private boolean[] allowWeakConfig = {false, false, false, false};
    private boolean respectIMMining = true;
    private boolean respectIMAttacking = true;
    private ConditionalBehavior restrictUse = ConditionalBehavior.SNEAKING_ONLY;
    private BalanceMode mode = BalanceMode.PRETTY_MUCH_BALANCED;
    private double dualDamageFactor = 0.8;
    private double twoHandedDamageFactor = 1.2;
    private double oneHandedDamageFactor = 1.0;
    private double dualSpeedFactor = 0.8;
    private double twoHandedSpeedFactor = 1.2;
    private double oneHandedSpeedFactor = 1.0;

    private static SimplyDualWieldingConfig INSTANCE;
    private static SimplyDualWieldingConfig SERVER_INSTANCE;
    private static final List<String> def = new ArrayList<>();
    static {def.add("minecraft:air");}
    private static final List<String> defUseList = new ArrayList<>();
    static {
        defUseList.add("minecraft:wooden_axe");
        defUseList.add("minecraft:stone_axe");
        defUseList.add("minecraft:iron_axe");
        defUseList.add("minecraft:golden_axe");
        defUseList.add("minecraft:diamond_axe");
        defUseList.add("minecraft:netherite_axe");
        defUseList.add("minecraft:wooden_shovel");
        defUseList.add("minecraft:stone_shovel");
        defUseList.add("minecraft:iron_shovel");
        defUseList.add("minecraft:golden_shovel");
        defUseList.add("minecraft:diamond_shovel");
        defUseList.add("minecraft:netherite_shovel");
        defUseList.add("minecraft:wooden_hoe");
        defUseList.add("minecraft:stone_hoe");
        defUseList.add("minecraft:iron_hoe");
        defUseList.add("minecraft:golden_hoe");
        defUseList.add("minecraft:diamond_hoe");
        defUseList.add("minecraft:netherite_hoe");
    }
    private static ListState listState = ListState.ATTACK;

    private SimplyDualWieldingConfig() {
        attackList = def;
        mineList = def;
        disableUseList = defUseList;
    }

    public SimplyDualWieldingConfig(boolean empty, ItemCat attacks, ItemCat mines, ConditionalBehavior restrictUse, boolean[] allowWeakConfig, BalanceMode mode) {
        this.empty = empty;
        this.attacks = attacks;
        this.mines = mines;
        this.restrictUse = restrictUse;
        this.allowWeakConfig = allowWeakConfig;
        this.attackList = def;
        this.mineList = def;
        this.disableUseList = defUseList;
        this.mode = mode;
    }

    public static SimplyDualWieldingConfig getInstance() {
        if (INSTANCE == null) {
            INSTANCE = new SimplyDualWieldingConfig();
        }
        return INSTANCE;
    }

    public static SimplyDualWieldingConfig getServerInstance() {
        return SERVER_INSTANCE;
    }

    private static void setServerInstance(SimplyDualWieldingConfig newInstance) {
        SERVER_INSTANCE = newInstance;
    }

    public void updateConfigs(SimplyDualWieldingConfig config) {
        this.empty = config.empty;
        this.attacks = config.attacks;
        this.mines = config.mines;
        this.restrictUse = config.restrictUse;
        setAttackItems(config.attackList);
        setMineItems(config.mineList);
        setDisableUseItems(config.disableUseList);
        this.allowWeakConfig = config.allowWeakConfig;
        this.respectIMMining = config.respectIMMining;
        this.respectIMAttacking = config.respectIMAttacking;
        this.mode = config.mode;
        this.dualDamageFactor = config.dualDamageFactor;
        this.twoHandedDamageFactor = config.twoHandedDamageFactor;
        this.oneHandedDamageFactor = config.oneHandedDamageFactor;
        this.dualSpeedFactor =  config.dualSpeedFactor;
        this.twoHandedSpeedFactor = config.twoHandedSpeedFactor;
        this.oneHandedSpeedFactor = config.oneHandedSpeedFactor;
    }

    static void setEmpty(boolean setter) {
        getInstance().empty = setter;
    }
    public boolean getEmpty() {
        return this.empty;
    }

    static void setRestrictUse(ConditionalBehavior setter) {
        getInstance().restrictUse = setter;
    }
    public ConditionalBehavior getRestrictUse() {
        return this.restrictUse;
    }

    static void setAttacks(ItemCat setter) {
        getInstance().attacks = setter;
    }
    public ItemCat getAttacks() {
        return this.attacks;
    }

    static void setMines(ItemCat setter) {
        getInstance().mines = setter;
    }
    public ItemCat getMines() {
        return this.mines;
    }

    public List<String> getAttackItems() {
        return this.attackList;
    }
    static void setAttackItems(List<String> newList) {
        getInstance().attackList = newList;
    }

    public List<String> getMineItems() {
        return this.mineList;
    }
    static void setMineItems(List<String> newList) {
        getInstance().mineList = newList;
    }

    public List<String> getDisableUseItems() {
        return this.disableUseList;
    }
    static void setDisableUseItems(List<String> newList) {
        getInstance().disableUseList = newList;
    }

    public boolean getRespectIMAttacking() {
        return this.respectIMAttacking;
    }

    static void setRespectIMAttacking(boolean newVal) {
        getInstance().respectIMAttacking = newVal;
    }

    public boolean getRespectIMMining() {
        return this.respectIMMining;
    }

    static void setRespectIMMining(boolean newVal) {
        getInstance().respectIMMining = newVal;
    }

    public BalanceMode getMode() {
        return mode;
    }
    public static void setMode(BalanceMode mode) {
        getInstance().mode = mode;
    }

    public double getDualDamageFactor() {
        return dualDamageFactor;
    }
    public static void setDualDamageFactor(double dualFactor) {
        getInstance().dualDamageFactor = dualFactor;
    }

    public double getTwoHandedDamageFactor() {
        return twoHandedDamageFactor;
    }
    public static void setTwoHandedDamageFactor(double twoHandedFactor) {
        getInstance().twoHandedDamageFactor = twoHandedFactor;
    }

    public double getOneHandedDamageFactor() {
        return oneHandedDamageFactor;
    }
    public static void setOneHandedDamageFactor(double oneHandedFactor) {
        getInstance().oneHandedDamageFactor = oneHandedFactor;
    }

    public double getDualSpeedFactor() {
        return this.dualSpeedFactor;
    }
    static void setDualSpeedFactor(double dualSpeedFactor) {
        getInstance().dualSpeedFactor = dualSpeedFactor;
    }

    public double getTwoHandedSpeedFactor() {
        return this.twoHandedSpeedFactor;
    }
    static void setTwoHandedSpeedFactor(double twoHandedSpeedFactor) {
        getInstance().twoHandedSpeedFactor = twoHandedSpeedFactor;
    }

    public double getOneHandedSpeedFactor() {
        return this.oneHandedSpeedFactor;
    }
    static void setOneHandedSpeedFactor(double oneHandedSpeedFactor) {
        getInstance().oneHandedSpeedFactor = oneHandedSpeedFactor;
    }

    public double[] getValues() {
        return new double[]{
                dualDamageFactor,
                oneHandedDamageFactor,
                twoHandedDamageFactor,
                dualSpeedFactor,
                oneHandedSpeedFactor,
                twoHandedSpeedFactor
        };
    }

    public static void onBalanceReceived(BalancePacket payload) {
        double[] values = payload.getValues();
        SERVER_INSTANCE.dualDamageFactor = values[0];
        SERVER_INSTANCE.oneHandedDamageFactor = values[1];
        SERVER_INSTANCE.twoHandedDamageFactor = values[2];
    }

    public static Set<class_2960> getSetFromList (List<String> list) {
        Set<class_2960> set = ConcurrentHashMap.newKeySet();
        for (String nam : list)
            set.add(class_2960.method_60654(nam));
        return set;
    }

    public static void onConfigReceived(ConfigPacket payload) {
        setServerInstance(payload.getHeldInstance());
    }

    public static void onListReceived(ListPacket listPacket) {
        List<String> list = listPacket.getList();
        for (String entry : list) {
            switch (listState) {
                case ATTACK:
                    if (entry.isEmpty())
                        listState = ListState.MINE;
                    else
                        SERVER_INSTANCE.attackList.add(entry);
                    break;
                case MINE:
                    if (entry.isEmpty())
                        listState = ListState.USE_DISABLED;
                    else
                        SERVER_INSTANCE.mineList.add(entry);
                    break;
                case USE_DISABLED:
                    if (entry.isEmpty())
                        listState = ListState.ATTACK;
                    else
                        if (entry.equals("def"))
                            SERVER_INSTANCE.disableUseList.addAll(defUseList);
                        else
                            SERVER_INSTANCE.disableUseList.add(entry);

            }
        }
    }

    private static class ErrorSupplier implements Function<String, Optional<class_2561>> {
        @Override
        public Optional<class_2561> apply(String entry) {
            entry = entry.toLowerCase();
            if (entry.indexOf(':') != entry.lastIndexOf(':'))
                return Optional.of(class_2561.method_43470("Enter a valid item TYPE! error code: 1"));
            String name = entry.substring(entry.indexOf(':') + 1).replaceAll("[^a-z0-9/._-]", "");
            if (!entry.equals(name)) {
                if (entry.indexOf(':') == -1)
                    return Optional.of(class_2561.method_43470("Enter a valid item TYPE! error code: 2"));
                String namespace = entry.substring(0,entry.indexOf(':')).replaceAll("[^a-z0-9/._-]", "");
                if (!entry.equals(namespace + ":" + name)) {
                    return Optional.of(class_2561.method_43470("Enter a valid item TYPE! error code: 3"));
                }
            }
            class_2960 id = class_2960.method_60654(entry);
            if (!class_7923.field_41178.method_10235().contains(id))
                return Optional.of(class_2561.method_43470("Enter a valid item TYPE! error code: 4"));
            return Optional.empty();
        }
    }
    static Function<String, Optional<class_2561>> getErrorSupplier() {
        return new ErrorSupplier();
    }

    static List<String> getDef() {
        return def;
    }

    public static List<String> getDefUseList() {return defUseList;}

    public boolean[] getAllowWeakConfig() {
        return this.allowWeakConfig;
    }

    public boolean getAllowWeakConfig(int i) {
        return this.allowWeakConfig[i];
    }

    public static void disconnect() {
        if (SERVER_INSTANCE != null)
            SERVER_INSTANCE = null;
    }

    private enum ListState {
        ATTACK,
        MINE,
        USE_DISABLED
    }

}
